class User < ActiveRecord::Base
  attr_accessor :password
  before_save :encrypt_password
  has_many :tests
  
  self.inheritance_column = :inheritance_type

  validates :username,
    {
      :length => {:in => 4..18, :too_long => "Tul hosszu"},
      presence: true,
      uniqueness: true
    }
  validates :password, confirmation: true, if: :password_required?

  def self.encrypt(pass, salt)
    Digest::SHA1.hexdigest(salt+pass)
  end

  def encrypt_password
    return if password.blank?
    if new_record?
      self.salt = SecureRandom.base64(8)
    end
    self.encrypted_password = User.encrypt(password, salt)
  end
  
  def self.authenticate(username, password)
    user = User.where(username: username).take
    user && user.authenticated?(password) ? user : nil
  end
  
  def authenticated?(pass)
    self.encrypted_password == User.encrypt(pass, salt)
  end
  
  def password_required?
    encrypted_password.blank? || !password.blank?
    # self.new_record? 
  end
end
